#    Police Operation Garden Exhibition
#    Copyright (C) 2016  Jannik Haberbosch
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os.path
import pygame
from code.modules import loading

pygame.init()


class Animation( object ):
	"""This class represents an animation which consists of 2 or more images
	played after one another and from the beginning again or in reversed mode.

	"""
	def __init__( self, _dir_path, _img_paths, _step, _interval, _bounce_mode = True ):
		"""Initialises an instaces of the class.

		"""
		self.image = None
		self.images = []

		
		self.dir_path = _dir_path
		self.img_paths = _img_paths
		self.step = _step
		self.interval = _interval
		self.bounce_mode = _bounce_mode

		self.current_image = 0
		self.n_images = len( self.img_paths ) - 1
		self.counter = 0

		self.init_images()
		self.set_current_image()

	def init_images( self ):
		"""Loads images and saves them in a list.

		"""
		for x in self.img_paths:
			self.images.append(
				loading.load_image(
					os.path.join( self.dir_path, x )
				)
			)


	def set_current_image( self ):
		"""Sets the current image.

		"""
		self.image = self.images[self.current_image]


	def update( self ):
		"""Updates the animation object.

		"""
		if self.counter >= self.interval:
			self.counter = 0
			if self.current_image == self.n_images:
				if self.bounce_mode:
					self.images.reverse()
				self.current_image = 0
			else:
				self.current_image += 1

			self.update_animation()
			
		else:
			self.counter += 1


	def update_animation( self ):
		"""Updates the animation if necessary

		"""
		self.image = self.images[self.current_image]
