#    Police Operation Garden Exhibition
#    Copyright (C) 2016  Jannik Haberbosch
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os.path

import pygame
from code.modules import loading

pygame.init()


class Area( pygame.sprite.Sprite ):
	"""This class represents the area, the entrance to the garden exhibition.

	"""
	collision_rectangles = []


	@staticmethod
	def init_class_variables( _area_settings ):
		"""Initialises class variables.

		"""
		Area.area_settings = _area_settings

		[ Area.collision_rectangles.append( pygame.Rect( *x ) )
		  for x in Area.area_settings["collision_rectangles"] ]


	def __init__( self, _area_settings ):

		super( Area, self ).__init__()

		self.area_settings = _area_settings

		self.image = loading.load_image(
			os.path.join( self.area_settings["dir_path"],
						  self.area_settings["image"] ) )

		self.rect = self.image.get_rect()
		self.rect.topleft = self.area_settings["position_top_left"]

		self.clipping_area_left = pygame.Rect( self.area_settings["clipping_area_left"] )
		self.clipping_area_center = pygame.Rect( self.area_settings["clipping_area_center"] )		
		self.clipping_area_right = pygame.Rect( self.area_settings["clipping_area_right"] )

		self.surface_left = pygame.sprite.Sprite()
		self.surface_center = pygame.sprite.Sprite()
		self.surface_right = pygame.sprite.Sprite()

		self.surface_left.image = pygame.Surface( ( 10, 10 ) )
		self.surface_left.rect = self.surface_left.image.get_rect()

		#self.take_photo()


	def update( self ):
		if pygame.mouse.get_pressed()[0]:
			pass #self.take_photo()


	def take_photo( self ):
		"""

		"""
		self.surface_left.image = self.image.subsurface( self.clipping_area_left )
		self.surface_left.rect = self.clipping_area_left

		pixelarray = pygame.PixelArray( self.surface_left.image )
		for row in range( len( pixelarray ) ):
			for col in range( len( pixelarray[row] ) ):
				c = self.surface_left.image.unmap_rgb( pixelarray[row, col] )
				g1 = ( c.r + c.g + c.b ) / 3
				c = pygame.Color( g1, g1, g1, 255 )
				pixelarray[row, col] = c
