#    Police Operation Garden Exhibition
#    Copyright (C) 2016  Jannik Haberbosch
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

import pygame
pygame.init()
pygame.mixer.pre_init(frequency=22050, size=-16, channels=2, buffer=256)

from code.classes.InfoPanel import InfoPanel

class Player( pygame.sprite.Sprite ):

	def __init__( self, _settings ):
		"""

		"""
		super( Player, self ).__init__()
		
		self.mouse_button_pressed = {
			"btn_left": False,
			"btn_center": False,
			"btn_right": False
		}
		
		self.already_pressed = False
		self.settings = _settings

		self.image = pygame.Surface( self.settings["haircross"]["size"] )
		self.image.fill( self.settings["haircross"]["colourkey"] )
		self.image.set_colorkey( self.settings["haircross"]["colourkey"] )
				
		self.rect = self.image.get_rect()

		pygame.draw.lines( self.image,
						   self.settings["haircross"]["colour"],
						   True,
						   self.settings["haircross"]["lines"] )


		self.player_hit_settings = self.settings["player_hit_settings"]
		self.player_hit_setting = self.player_hit_settings["kill"]
		self.player_hit_mode = "kill"

		self.infopanel = InfoPanel( self.settings["info_panel_settings"] )

		self.score = 0
		self.faulty_ones = 0
		self.acci_hit = 0
		self.fixed = 0

		# sounds here
		self.sound_ah_almost = pygame.mixer.Sound( self.settings["sounds"]["ah_almost"] )
		self.sound_alright = pygame.mixer.Sound( self.settings["sounds"]["alright"] )
		self.sound_hmm_not_quite = pygame.mixer.Sound( self.settings["sounds"]["hmm_not_quite"] )
		self.sound_sorry_mate = pygame.mixer.Sound( self.settings["sounds"]["sorry_mate"] )
		self.sound_well_done = pygame.mixer.Sound( self.settings["sounds"]["well_done"] )
		self.sound_and_another_one_fixed = pygame.mixer.Sound( self.settings["sounds"]["and_another_one_fixed"] )
		self.sound_what_am_i_doing = pygame.mixer.Sound( self.settings["sounds"]["what_am_i_doing"] )
		self.sound_wrong_source_code = pygame.mixer.Sound( self.settings["sounds"]["wrong_source_code"] )
		self.sound_good_job = pygame.mixer.Sound( self.settings["sounds"]["good_job"] )		
	
		
	def update( self, _events, _visitor_class ):
		"""

		"""
		for e in _events:
			if e.type == pygame.MOUSEBUTTONDOWN:
				if e.button == 1 and not self.mouse_button_pressed["btn_left"]:
					_visitor_class.check_routine_hit( self )	
					self.mouse_button_pressed["btn_left"] = True
				if e.button == 3 and not self.mouse_button_pressed["btn_right"]:
					self.mouse_button_pressed["btn_right"] = True
					_visitor_class.check_routine_analyse( self.rect )

			if e.type == pygame.MOUSEBUTTONUP:
				if e.button == 1:
					self.mouse_button_pressed["btn_left"] = False
				if e.button == 3:
					self.mouse_button_pressed["btn_right"] = False

			if e.type == pygame.KEYDOWN:
				if e.key == pygame.K_q:
					self.player_hit_setting = self.player_hit_settings["kill"]
					self.player_hit_mode = "kill"
				elif e.key == pygame.K_w:
					self.player_hit_setting = self.player_hit_settings["robot_python_fix"]
					self.player_hit_mode = "python"
				elif e.key == pygame.K_e:
					self.player_hit_setting = self.player_hit_settings["robot_php_fix"]
					self.player_hit_mode = "php"
				elif e.key == pygame.K_r:
					self.player_hit_setting = self.player_hit_settings["robot_javascript_fix"]
					self.player_hit_mode = "javascript"


		self.infopanel.update( self.score, self.player_hit_mode, self.faulty_ones, self.acci_hit, self.fixed )
		self.update_haircross()


	def update_haircross( self ):
		"""

		"""
		self.rect.center = pygame.mouse.get_pos()
					
