#    Police Operation Garden Exhibition
#    Copyright (C) 2016  Jannik Haberbosch
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os.path
import pygame
pygame.init()

# Some basic colours which we can use in the game.
COLOUR_GREEN = pygame.Color( 0, 255, 0, 0 )
COLOUR_BLACK = pygame.Color( 0, 0, 0, 0 )
COLOUR_GREY = pygame.Color( 50, 50, 50 )
COLOUR_WHITE = pygame.Color( 255, 255, 255, 0 )
COLOUR_RED = pygame.Color( 255, 0, 0, 0 )

# System settings.
GAME_WINDOW = {
	"resolution": ( 1366, 768 ),
	"flags": ( pygame.FULLSCREEN, ),
	"background_color": COLOUR_BLACK
}

GAME_CLOCK = {
	"fps": 100
}

GAME_CURSOR = {
	"visible": False
}


# Hair cross settings.
HAIR_CROSS = {
	"dimensions": ( 30, 30 ),
	"colour": COLOUR_GREY,
	"background_colour": COLOUR_BLACK,
	"horizontal_line": {
		"start_pos": ( 0, 15 ),
		"end_pos": ( 30, 15 ),
		"width": 1
	},
	"vertical_line": {
		"start_pos": ( 15, 0 ),
		"end_pos": ( 15, 30 ),
		"width": 1
	}
}

# Player settings.
PLAYER_SETTINGS = {
	"haircross": {
		"colour": COLOUR_GREY,
		"size": ( 40, 40 ),
		"lines": ( ( 1, 1 ), ( 39, 1 ), ( 39, 39 ), ( 1, 39 ) ),
		"colourkey": COLOUR_BLACK
	},
	"player_hit_settings": {
		"kill": "kill",
		"robot_python_fix": "robot_python_fix",
		"robot_php_fix": "robot_php_fix",
		"robot_javascript_fix": "robot_javascript_fix"
	},
	"info_panel_settings": {
		"size": ( 350, 768 ),
		"background_colour": COLOUR_BLACK,
		"position_left_top": ( 0, 0 ),
		"border_colour": COLOUR_GREY,
		"border_points": ( ( 4, 4 ), ( 344, 4 ), ( 344, 763 ), ( 4, 763 ) ),
		"border_width": 10,
		"fonts": {
			"font_heading": {
				"font_dir": os.path.join( os.getcwd(), "font" ),
				"font_name": "Ubuntu_R.ttf",
				"font_size": 20
			},
			"font_normal": {
				"font_dir": os.path.join( os.getcwd(), "font" ),
				"font_name": "Ubuntu_R.ttf",
				"font_size": 15
			},
			"font_small": {
				"font_dir": os.path.join( os.getcwd(), "font" ),
				"font_name": "Ubuntu_R.ttf",
				"font_size": 12
			},			
		},
		"texts": {
			"heading": {
				"text": "LAWNMOWER ROBOTS HELPING",
				"pos": ( 20, 20 ), # always left top,
				"size": "heading",
				"colour": COLOUR_WHITE
			},
			"heading1": {
				"text": "AT A GARDEN EXHIBITION",
				"pos": ( 20, 40 ), # always left top,
				"size": "heading",
				"colour": COLOUR_WHITE	
			},
			"pyweekentry": {
				"text": "PyWeek #22 entry by Master47",
				"pos": ( 20, 60 ), # always left top,
				"size": "small",
				"colour": COLOUR_WHITE	
			},
			"pyweekentry2": {
				"text": "Theme: Don't let him in here.",
				"pos": ( 20, 70 ), # always left top,
				"size": "small",
				"colour": COLOUR_WHITE	
			},
			"help1": {
				"text": "Press 'Return' to start a new game.",
				"pos": ( 20, 100 ),
				"size": "small",
				"colour": COLOUR_GREEN
			},
			"help2": {
				"text": "Press 'Esc' to quit the game or end the current round.",
				"pos": ( 20, 115 ),
				"size": "small",
				"colour": COLOUR_GREEN
			},
			"selected_right_mode": {
				"text": "Selected 'left click' mode:",
				"pos": ( 20, 200 ),
				"size": "small",
				"colour": COLOUR_RED			
			},
			"current_score": {
				"text": "Current Score:",
				"pos": ( 20, 240 ),
				"size": "small",
				"colour": COLOUR_WHITE				
			},
			"n_robots_faulty": {
				"text": "Faulty lawnmower robots at the exhibition:",
				"pos": ( 20, 280 ),
				"size": "small",
				"colour": COLOUR_WHITE
			},
			"ok_robots_killed": {
				"text": "O.K. lawnmower robots accidently killed:",
				"pos": ( 20, 320 ),
				"size": "small",
				"colour": COLOUR_WHITE
			},
			"robots_fixed": {
				"text": "Lawnmower robots fixed:",
				"pos": ( 20, 360 ),
				"size": "small",
				"colour": COLOUR_WHITE			
			}
		},
		"left_click_modes": ( "kill", "python fix", "php fix", "javascript fix" ),
		"left_click": {
			"pos": ( 200, 200 ),
			"colour": COLOUR_WHITE,
			"bg_colour": COLOUR_BLACK			
		},
		"score": {
			"colour": COLOUR_WHITE,
			"pos": ( 125, 240 ),
			"bg_colour": COLOUR_BLACK
		},
		"acci_hit": {
			"colour": COLOUR_WHITE,
			"pos": ( 270, 320 ),
			"bg_colour": COLOUR_BLACK
		},
		"rob_fix": {
			"colour": COLOUR_WHITE,
			"pos": ( 190, 360 ),
			"bg_colour": COLOUR_BLACK
		},
		"faulty_ones": {
			"colour": COLOUR_WHITE,
			"pos": ( 270, 280 ),
			"bg_colour": COLOUR_BLACK		
		}
	},
	"sounds": {
		"ah_almost": os.path.join( os.getcwd(), "sfx", "player_ah_almost.wav" ),
		"alright": os.path.join( os.getcwd(), "sfx", "player_alright.wav" ),
		"hmm_not_quite": os.path.join( os.getcwd(), "sfx", "player_hmm_not_quite.wav" ),
		"well_done": os.path.join( os.getcwd(), "sfx", "player_well_done.wav" ),
		"sorry_mate": os.path.join( os.getcwd(), "sfx", "player_sorry_mate.wav" ),
		"and_another_one_fixed": os.path.join( os.getcwd(), "sfx", "player_and_another_one_fixed.wav" ),
		"what_am_i_doing": os.path.join( os.getcwd(), "sfx", "player_what_am_i_doing.wav" ),
		"wrong_source_code": os.path.join( os.getcwd(), "sfx", "player_wrong_source_code.wav" ),
		"good_job": os.path.join( os.getcwd(), "sfx", "player_good_job.wav" )
	}
}

# Visitor settings.
VISITOR_SETTINGS = {
	"visitor_creation_settings": {
		"max_interval_range": 500,
		"min_interval_range": 25,
		"interval_range": ( 50, 400 )
	},
	"visitors": (
		{
			"animation": {
				"dir_path": os.path.join( os.getcwd(), "gfx" ),
				"images": ( "robot_1.png",
							"robot_2.png",
							"robot_3.png",
							"robot_4.png",
							"robot_5.png",
							"robot_6.png" ),
				"step": 1,
				"interval": 5
			},
			"states": {
				"robot_ok": "robot_ok.png",
				"robot_error": "robot_error.png",
				"robot_python_fix": "robot_python_fix.png",
				"robot_php_fix": "robot_php_fix.png",
				"robot_javascript_fix": "robot_javascript_fix.png"
			},
			"dir_path": os.path.join( os.getcwd(), "gfx" ),
			"show_state_timespan": 100, # frames. equals 1 second.			
			"state_images": {
				"dir_path": os.path.join( os.getcwd(), "gfx" ),
				"image_state_ok": "robot_ok.png",
				"image_state_error": "robot_error.png",

			},
			"start_positions": {
				1: {
					"start_pos_x_range": ( 540, 1240 ),
					"start_pos_y_range": ( -50, -25 )
				},
			},
			"speed": ( 5, 40 ), # Will be divided by 10.
			"direction": 180
		},
	)
}

# Area settings.
AREA_SETTINGS = {
	"collision_rectangles": (
		( 0, 0, 117, 768 ),
		( 0, 0, 572, 114),
		( 807, 0, 557, 114 ),
		( 1252, 112, 114, 654 ),
		( 626, 240, 116, 193 )
	),
	"dir_path": os.path.join( os.getcwd(), "gfx" ),
	"image": "ingame_background.png",
	"position_top_left": ( 0, 0 ),
	"clipping_area_left": ( 100, 0, 300, 766 ),
	"clipping_area_center": ( 0, 0, 100, 100 ),
	"clipping_area_right": ( 0, 0, 100, 100 )
}
